@@ -62,9 +62,10 @@ DevicesPage::DevicesPage(QWidget *p)
     : QWidget(p)
 {
     setupUi(this);
-    copyAction = ActionCollection::get()->createAction("copytolibrary", i18n("Copy To Library"), Icons::importIcon);
+    copyAction = ActionCollection::get()->createAction("copytolibrary", i18n("Copy To Library"), Icons::self()->importIcon);
     copyToLibraryButton->setDefaultAction(copyAction);
     syncAction = ActionCollection::get()->createAction("syncdevice", i18n("Sync"), "folder-sync");
+    searchButton->setDefaultAction(StdActions::self()->searchAction);
     connect(syncAction, SIGNAL(triggered()), this, SLOT(sync()));
     #ifdef ENABLE_REMOTE_DEVICES
     forgetDeviceAction=ActionCollection::get()->createAction("forgetdevice", i18n("Forget Device"), "list-remove");
@@ -126,7 +127,6 @@ DevicesPage::DevicesPage(QWidget *p)
     #endif
     menuButton->setMenu(menu);
     proxy.setSourceModel(DevicesModel::self());
-    view->setTopText(i18n("Devices"));
     view->setModel(&proxy);
     view->setRootIsDecorated(false);
 }
@@ -144,7 +144,7 @@ void DevicesPage::clear()
 QString DevicesPage::activeFsDeviceUdi() const
 {
     Device *dev=activeFsDevice();
-    return dev ? dev->udi() : QString();
+    return dev ? dev->id() : QString();
 }
 
 Device * DevicesPage::activeFsDevice() const
@@ -247,6 +247,17 @@ void DevicesPage::addSelectionToPlaylist(const QString &name, bool replace, quin
     }
 }
 
+void DevicesPage::refresh()
+{
+    view->setLevel(0);
+    DevicesModel::self()->clearImages();
+    if (ItemView::Mode_SimpleTree==view->viewMode() || ItemView::Mode_DetailedTree==view->viewMode()) {
+        for (int i=0; i<DevicesModel::self()->rowCount(QModelIndex()); ++i) {
+            view->setExpanded(proxy.mapFromSource(DevicesModel::self()->index(i, 0, QModelIndex())));
+        }
+    }
+}
+
 void DevicesPage::itemDoubleClicked(const QModelIndex &)
 {
 //     const QModelIndexList selected = view->selectedIndexes();
@@ -315,8 +326,8 @@ void DevicesPage::controlActions()
             #endif
             canPlay=dev->canPlaySongs();
             if (udi.isEmpty()) {
-                udi=dev->udi();
-            } else if (udi!=dev->udi()) {
+                udi=dev->id();
+            } else if (udi!=dev->id()) {
                 singleUdi=false;
             }
             if (!haveTracks) {
@@ -368,7 +379,7 @@ void DevicesPage::copyToLibrary()
     }
     QString udi;
     if (MusicLibraryItem::Type_Root==item->itemType()) {
-        udi=static_cast<Device *>(item)->udi();
+        udi=static_cast<Device *>(item)->id();
     }
 
     if (udi.isEmpty()) {
@@ -410,7 +421,7 @@ void DevicesPage::refreshDevice()
 
     if (MusicLibraryItem::Type_Root==item->itemType()) {
         Device *dev=static_cast<Device *>(item);
-        QString udi=dev->udi();
+        QString udi=dev->id();
         bool full=true;
 
         if (Device::AudioCd==dev->devType()) {
@@ -428,7 +439,8 @@ void DevicesPage::refreshDevice()
                 return;
             }
             #else
-            if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Lookup album and track details?"), i18n("Refresh"))) {
+            if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Lookup album and track details?"),
+                                                          i18n("Refresh"), GuiItem(i18n("Refresh")), StdGuiItem::cancel())) {
                 return;
             }
             #endif
@@ -475,7 +487,7 @@ void DevicesPage::deleteSongs()
     }
     QString udi;
     if (MusicLibraryItem::Type_Root==item->itemType()) {
-        udi=static_cast<Device *>(item)->udi();
+        udi=static_cast<Device *>(item)->id();
     }
 
     if (udi.isEmpty()) {
@@ -485,7 +497,8 @@ void DevicesPage::deleteSongs()
     QList<Song> songs=DevicesModel::self()->songs(mapped);
 
     if (!songs.isEmpty()) {
-        if (MessageBox::Yes==MessageBox::warningYesNo(this, i18n("Are you sure you wish to remove the selected songs?\nThis cannot be undone."))) {
+        if (MessageBox::Yes==MessageBox::warningYesNo(this, i18n("Are you sure you wish to delete the selected songs?\nThis cannot be undone."),
+                                                      i18n("Delete Songs"), StdGuiItem::del(), StdGuiItem::cancel())) {
             emit deleteSongs(udi, songs);
         }
         view->clearSelection();
@@ -509,9 +522,9 @@ void DevicesPage::forgetRemoteDevice()
     if (!dev) {
         return;
     }
-    QString udi=dev->udi();
+    QString udi=dev->id();
     QString devName=dev->data();
-    if (MessageBox::Yes==MessageBox::warningYesNo(this, i18n("Are you sure you wish to forget '%1'?").arg(devName))) {
+    if (MessageBox::Yes==MessageBox::warningYesNo(this, i18n("Are you sure you wish to forget <b>%1</b>?", devName))) {
         DevicesModel::self()->removeRemoteDevice(udi);
     }
     #endif
@@ -529,10 +542,11 @@ void DevicesPage::toggleDevice()
     if (MusicLibraryItem::Type_Root==item->itemType()) {
         Device *dev=static_cast<Device *>(item);
         if (dev->isConnected() &&
-            MessageBox::No==MessageBox::warningYesNo(this,
-                                                     Device::AudioCd==dev->devType()
-                                                        ? i18n("Are you sure you wish to eject Audio CD '%1 - %2'?").arg(dev->data()).arg(dev->subText())
-                                                        : i18n("Are you sure you wish to disconnect '%1'?").arg(dev->data()))) {
+            (Device::AudioCd==dev->devType()
+                ? MessageBox::No==MessageBox::warningYesNo(this, i18n("Are you sure you wish to eject Audio CD <b>%1 - %2</b>?", dev->data(), dev->subText()),
+                                                           i18n("Eject"), GuiItem(i18n("Eject")), StdGuiItem::cancel())
+                : MessageBox::No==MessageBox::warningYesNo(this, i18n("Are you sure you wish to disconnect <b>%1</b>?", dev->data()),
+                                                           i18n("Disconnect"), GuiItem(i18n("Disconnect")), StdGuiItem::cancel()))) {
             return;
         }
         static_cast<Device *>(item)->toggle();
@@ -565,7 +579,7 @@ void DevicesPage::sync()
 
     if (MusicLibraryItem::Type_Root==item->itemType()) {
         SyncDialog *dlg=new SyncDialog(this);
-        dlg->sync(static_cast<Device *>(item)->udi());
+        dlg->sync(static_cast<Device *>(item)->id());
     }
 }
 
