@@ -46,8 +46,12 @@
 #include "mpdconnection.h"
 #include "song.h"
 #include "config.h"
-#ifdef PHONON_FOUND
+#ifdef ENABLE_HTTP_STREAM_PLAYBACK
+#if QT_VERSION < 0x050000
 #include <phonon/mediaobject.h>
+#else
+#include <QtMultimedia/QMediaPlayer>
+#endif
 #endif
 
 class Action;
@@ -58,12 +62,8 @@ class AlbumsPage;
 class FolderPage;
 class PlaylistsPage;
 class DynamicPage;
-class LyricsPage;
 class StreamsPage;
-#ifdef ENABLE_ONLINE_SERVICES
 class OnlineServicesPage;
-#endif
-class InfoPage;
 #ifdef ENABLE_DEVICES_SUPPORT
 class DevicesPage;
 #endif
@@ -80,13 +80,19 @@ class VolumeControl;
 class TrayItem;
 class GtkProxyStyle;
 
-// Dummy class so that when class name is saved to the config file, we get a more meaningful name than QWidget!!!
+// Dummy classes so that when class name is saved to the config file, we get a more meaningful name than QWidget!!!
 class PlayQueuePage : public QWidget
 {
     Q_OBJECT
 public:
     PlayQueuePage(QWidget *p) : QWidget(p) { }
 };
+class ContextPage : public QWidget
+{
+    Q_OBJECT
+public:
+    ContextPage(QWidget *p) : QWidget(p) { }
+};
 
 class DeleteKeyEventHandler : public QObject
 {
@@ -102,7 +108,7 @@ private:
 class VolumeSliderEventHandler : public QObject
 {
 public:
-    VolumeSliderEventHandler(MainWindow *w);
+    VolumeSliderEventHandler(MainWindow *w) : QObject((QObject *)w), window(w) { }
 protected:
     bool eventFilter(QObject *obj, QEvent *event);
 protected:
@@ -137,14 +143,11 @@ public:
         PAGE_PLAYLISTS,
         PAGE_DYNAMIC,
         PAGE_STREAMS,
-        #ifdef ENABLE_ONLINE_SERVICES
         PAGE_ONLINE,
-        #endif
-        PAGE_LYRICS,
-        PAGE_INFO
         #ifdef ENABLE_DEVICES_SUPPORT
-        , PAGE_DEVICES
+        PAGE_DEVICES,
         #endif
+        PAGE_CONTEXT
     };
 
     Q_PROPERTY(int volume READ mpdVolume WRITE setMpdVolume)
@@ -184,11 +187,12 @@ Q_SIGNALS:
     void enableOutput(int id, bool);
     void setPriority(const QList<qint32> &ids, quint8 priority);
     void addSongsToPlaylist(const QString &name, const QStringList &files);
+    void addAndPlay(const QString &file);
 
 public Q_SLOTS:
     void showError(const QString &message, bool showActions=false);
     void showInformation(const QString &message);
-    void showPage(const QString &page, bool focusSearch);
+    void showPage(const QString &page, bool showSearch);
     void dynamicStatus(const QString &message);
     void hideWindow();
     void restoreWindow();
@@ -202,7 +206,6 @@ public Q_SLOTS:
     void messageWidgetVisibility(bool v);
     void mpdConnectionStateChanged(bool connected);
     void playQueueItemsSelected(bool s);
-    void showVolumeControl();
     void showPreferencesDialog();
     void quit();
     void updateSettings();
@@ -217,7 +220,6 @@ public Q_SLOTS:
     void showServerInfo();
     void toggleStream(bool s);
     void stopPlayback();
-    void stopImmediately();
     void stopAfterCurrentTrack();
     void stopAfterTrack();
     void playPauseTrack();
@@ -248,6 +250,7 @@ public Q_SLOTS:
     void updatePlayQueueStats(int songs, quint32 time);
     void copyTrackInfo();
     void expandOrCollapse(bool saveCurrentSize=true);
+    void showSongInfo();
     void fullScreen();
     void sidebarModeChanged();
     void currentTabChanged(int index);
@@ -259,21 +262,19 @@ public Q_SLOTS:
     void showPlaylistsTab() { showTab(PAGE_PLAYLISTS); }
     void showDynamicTab() { showTab(PAGE_DYNAMIC); }
     void showStreamsTab() { showTab(PAGE_STREAMS); }
-    void showOnlineTab() {
-        #ifdef ENABLE_ONLINE_SERVICES
-        showTab(PAGE_ONLINE);
-        #endif
-    }
-    void showLyricsTab() { showTab(PAGE_LYRICS); }
-    void showInfoTab() { showTab(PAGE_INFO); }
+    void showOnlineTab() { showTab(PAGE_ONLINE); }
+    void showContextTab() { showTab(PAGE_CONTEXT); }
     void showDevicesTab() {
         #ifdef ENABLE_DEVICES_SUPPORT
         showTab(PAGE_DEVICES);
         #endif
     }
     void toggleSplitterAutoHide();
+    void toggleMonoIcons();
     void locateTrack();
     void locateArtist(const QString &artist);
+    void locateAlbum(const QString &artist, const QString &album);
+    void playSong(const QString &song);
     void editTags();
     void editPlayQueueTags();
     void organiseFiles();
@@ -284,7 +285,7 @@ public Q_SLOTS:
     void replayGain();
     void setCover();
     void goBack();
-    void focusSearch();
+    void showSearch();
     void expandAll();
     void collapseAll();
     void checkMpdDir();
@@ -333,7 +334,6 @@ private:
     Action *nextTrackAction;
     Action *playPauseTrackAction;
     Action *stopPlaybackAction;
-    Action *stopImmediatelyAction;
     Action *stopAfterCurrentTrackAction;
     Action *stopAfterTrackAction;
     Action *increaseVolumeAction;
@@ -350,11 +350,13 @@ private:
     Action *repeatPlayQueueAction;
     Action *singlePlayQueueAction;
     Action *consumePlayQueueAction;
+    Action *searchPlayQueueAction;
     Action *setPriorityAction;
-    #ifdef PHONON_FOUND
+    #ifdef ENABLE_HTTP_STREAM_PLAYBACK
     Action *streamPlayAction;
     #endif
     Action *expandInterfaceAction;
+    Action *songInfoAction;
     Action *fullScreenAction;
     Action *quitAction;
     Action *restoreAction;
@@ -365,23 +367,19 @@ private:
     Action *foldersTabAction;
     Action *playlistsTabAction;
     Action *dynamicTabAction;
-    Action *lyricsTabAction;
     Action *streamsTabAction;
-    #ifdef ENABLE_ONLINE_SERVICES
     Action *onlineTabAction;
-    #endif
     #ifdef TAGLIB_FOUND
     Action *editPlayQueueTagsAction;
     #endif
-    Action *infoTabAction;
     #ifdef ENABLE_DEVICES_SUPPORT
     Action *devicesTabAction;
     #endif
-    Action *searchAction;
     Action *expandAllAction;
     Action *collapseAllAction;
     Action *serverInfoAction;
     QAction *autoHideSplitterAction;
+    QAction *monoIconsAction;
     TrayItem *trayItem;
     QPoint lastPos;
     QSize expandedSize;
@@ -393,12 +391,9 @@ private:
     FolderPage *folderPage;
     PlaylistsPage *playlistsPage;
     DynamicPage *dynamicPage;
-    LyricsPage *lyricsPage;
     StreamsPage *streamsPage;
-    #ifdef ENABLE_ONLINE_SERVICES
     OnlineServicesPage *onlinePage;
-    #endif
-    InfoPage *infoPage;
+    QWidget *contextPage;
     #ifdef ENABLE_DEVICES_SUPPORT
     DevicesPage *devicesPage;
     #endif
@@ -407,6 +402,7 @@ private:
     GnomeMediaKeys *gnomeMediaKeys;
     GtkProxyStyle *gtkStyle;
     #endif // Q_OS_WIN
+    QTimer *statusTimer;
     QTimer *playQueueSearchTimer;
     #ifdef Q_OS_LINUX
     QTimer *mpdAccessibilityTimer;
@@ -433,9 +429,13 @@ private:
     int origVolume;
     int lastVolume;
     StopState stopState;
-    #ifdef PHONON_FOUND
-    bool phononStreamEnabled;
-    Phonon::MediaObject *phononStream;
+    #ifdef ENABLE_HTTP_STREAM_PLAYBACK
+    bool httpStreamEnabled;
+    #if QT_VERSION < 0x050000
+    Phonon::MediaObject *httpStream;
+    #else
+    QMediaPlayer *httpStream;
+    #endif
     #endif
 
     friend class VolumeSliderEventHandler;
