@@ -576,16 +576,22 @@ quint32 MusicLibraryItemRoot::fromXML(QXmlStreamReader &reader, const QDateTime
                     if (!baseFolder.isEmpty() && song.file.startsWith(baseFolder)) {
                         song.file=song.file.mid(baseFolder.length());
                     }
-                    song.genre=attributes.value(constGenreAttribute).toString();
-                    if (song.genre.isEmpty()) {
-                        song.genre=unknown;
+                    QString genre=attributes.value(constGenreAttribute).toString();
+                    if (genre.isEmpty() ) {
+                        if (song.genre.isEmpty()) {
+                            song.genre=unknown;
+                        }
+                    } else {
+                        song.genre=genre;
                     }
-                    song.artist=attributes.value(constArtistAttribute).toString();
-                    if (song.artist.isEmpty()) {
+                    if (attributes.hasAttribute(constArtistAttribute)) {
+                        song.artist=attributes.value(constArtistAttribute).toString();
+                    } else {
                         song.artist=artistItem->data();
                     }
-                    song.albumartist=attributes.value(constAlbumArtistAttribute).toString();
-                    if (song.albumartist.isEmpty()) {
+                    if (attributes.hasAttribute(constAlbumArtistAttribute)) {
+                        song.albumartist=attributes.value(constAlbumArtistAttribute).toString();
+                    } else {
                         song.albumartist=artistItem->data();
                     }
 
@@ -651,6 +657,7 @@ quint32 MusicLibraryItemRoot::fromXML(QXmlStreamReader &reader, const QDateTime
             // ...so, just apply grouping!
             groupSingleTracks();
             groupMultipleArtists();
+            updateGenres();
         } else {
             // Mixed grouping, so need to redo from scratch...
             toggleGrouping();
@@ -719,12 +726,18 @@ void MusicLibraryItemRoot::toggleGrouping()
     }
 
     // Library rebuilt, now apply any grouping...
+    applyGrouping();
+}
+
+void MusicLibraryItemRoot::applyGrouping()
+{
     if (MPDParseUtils::groupSingle()) {
         groupSingleTracks();
     }
     if (MPDParseUtils::groupMultiple()) {
         groupMultipleArtists();
     }
+    updateGenres();
 }
 
 void MusicLibraryItemRoot::clearItems()
@@ -749,6 +762,9 @@ bool MusicLibraryItemRoot::update(const QSet<Song> &songs)
     foreach (const Song &s, added) {
         addSongToList(s);
     }
+    if (updatedSongs) {
+        updateGenres();
+    }
     return updatedSongs;
 }
 
@@ -960,14 +976,19 @@ void MusicLibraryItemRoot::clearImages()
     }
 }
 
+QString MusicLibraryItemRoot::artistName(const Song &s)
+{
+    if (Song::Standard==s.type || (Song::Playlist==s.type && !s.albumArtist().isEmpty())) {
+        return s.albumArtist();
+    }
+    return i18n("Various Artists");
+}
+
 QString MusicLibraryItemRoot::songArtist(const Song &s) const
 {
     if (isFlat || !supportsAlbumArtist) {
         return s.artist;
     }
 
-    if (Song::Standard==s.type || (Song::Playlist==s.type && !s.albumArtist().isEmpty())) {
-        return s.albumArtist();
-    }
-    return i18n("Various Artists");
+    return artistName(s);
 }
