@@ -568,14 +568,7 @@ MusicLibraryItemRoot * MPDParseUtils::parseLibraryItems(const QByteArray &data,
             }
         }
     }
-
-    if (groupSingleTracks) {
-        rootItem->groupSingleTracks();
-    }
-    if (groupMultipleArtists) {
-        rootItem->groupMultipleArtists();
-    }
-
+    rootItem->applyGrouping();
     return rootItem;
 }
 
@@ -669,15 +662,33 @@ QString MPDParseUtils::formatDuration(const quint32 totalseconds)
     #endif
 }
 
+static const QString constHashReplacement=QLatin1String("${hash}");
+
 QString MPDParseUtils::addStreamName(const QString &url, const QString &name)
 {
-    return name.isEmpty() ? url : (url+"#"+name);
+    if (name.isEmpty()) {
+        return url;
+    }
+
+    QUrl u(url);
+    QString n(name);
+    while (n.contains("#")) {
+        n=n.replace("#", constHashReplacement);
+    }
+    if (u.path().isEmpty()) {
+        return url+"/#"+n;
+    }
+    return url+"#"+n;
 }
 
 QString MPDParseUtils::getStreamName(const QString &url)
 {
     int idx=url.lastIndexOf('#');
-    return -1==idx ? QString() : url.mid(idx+1);
+    QString name=-1==idx ? QString() : url.mid(idx+1);
+    while (name.contains(constHashReplacement)) {
+        name.replace(constHashReplacement, "#");
+    }
+    return name;
 }
 
 QString MPDParseUtils::getAndRemoveStreamName(QString &url)
@@ -687,6 +698,9 @@ QString MPDParseUtils::getAndRemoveStreamName(QString &url)
         return QString();
     }
     QString name=url.mid(idx+1);
+    while (name.contains(constHashReplacement)) {
+        name.replace(constHashReplacement, "#");
+    }
     url=url.left(idx);
     return name;
 }
