@@ -104,6 +104,9 @@ bool Song::operator<(const Song &o) const
 
 int Song::compareTo(const Song &o) const
 {
+    if (type!=o.type) {
+        return type<o.type ? -1 : 1;
+    }
     if (SingleTracks==type) {
         int compare=artistSong().localeAwareCompare(artistSong());
         if (0!=compare) {
@@ -123,9 +126,6 @@ int Song::compareTo(const Song &o) const
     if (disc!=o.disc) {
         return disc<o.disc ? -1 : 1;
     }
-    if (type!=o.type) {
-        return type<o.type ? -1 : 1;
-    }
     if (track!=o.track) {
         return track<o.track ? -1 : 1;
     }
@@ -256,8 +256,12 @@ void Song::clear()
     type = Standard;
 }
 
-QString Song::formattedTime(quint32 seconds)
+QString Song::formattedTime(quint32 seconds, bool zeroIsUnknown)
 {
+    if (0==seconds && zeroIsUnknown) {
+        return i18n("Unknown");
+    }
+
     static const quint32 constHour=60*60;
     if (seconds>constHour) {
         return MPDParseUtils::formatDuration(seconds);
@@ -298,7 +302,7 @@ QString Song::entryName() const
         return file;
     }
 
-    return i18nc("Song\nArtist\nAlbum", "%1\n%2\n%3").arg(title).arg(artist).arg(album);
+    return i18nc("Song\nArtist\nAlbum", "%1\n%2\n%3", title, artist, album);
 }
 
 QString Song::artistSong() const
@@ -391,3 +395,23 @@ bool Song::capitalise()
 
     return artist!=origArtist || albumartist!=origAlbumArtist || album!=origAlbum || title!=origTitle;
 }
+
+QString Song::basicArtist() const
+{
+    if (!albumartist.isEmpty() && !artist.isEmpty() && albumartist.length()<artist.length() && artist.startsWith(albumartist)) {
+        return albumartist;
+    }
+
+    QStringList toStrip=QStringList() << QLatin1String("ft. ") << QLatin1String("feat. ") << QLatin1String("featuring ");
+    QStringList prefixes=QStringList() << QLatin1String(" ") << QLatin1String(" (") << QLatin1String(" [");
+
+    foreach (const QString s, toStrip) {
+        foreach (const QString p, prefixes) {
+            int strip = artist.toLower().indexOf(p+s);
+            if (-1!=strip) {
+                return artist.mid(0, strip);
+            }
+        }
+    }
+    return artist;
+}
