@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,14 +24,23 @@
 #ifndef GTKSTYLE_H
 #define GTKSTYLE_H
 
-class QStyleOptionViewItemV4;
+#include <QStyleOption>
 class QPainter;
+class QWidget;
+
+#include <QString>
 
 namespace GtkStyle
 {
     extern bool isActive();
     extern bool mimicWidgets();
     extern void drawSelection(const QStyleOptionViewItemV4 &opt, QPainter *painter, double opacity);
+    extern QString themeName();
+    extern QString iconTheme();
+    extern void applyTheme(QWidget *widget);
+    extern void cleanup();
+    extern bool useSymbolicIcons();
+    extern bool useLightIcons();
 }
 
 #endif
