@@ -33,6 +33,7 @@ class QAction;
 class QTimer;
 class GroupedView;
 class ActionItemDelegate;
+class MessageOverlay;
 
 class ViewEventHandler : public QObject
 {
@@ -80,10 +81,10 @@ public:
         Role_ImageSize = Qt::UserRole+256,
         Role_MainText,
         Role_SubText,
+        Role_TitleText,
         Role_Image,
         Role_Capacity,
         Role_CapacityText,
-        Role_Search,
         Role_Actions
     };
 
@@ -91,16 +92,13 @@ public:
     static QString modeStr(Mode m);
 
     static void setup();
-    static void setForceSingleClick(bool v);
-    static bool getForceSingleClick();
 
-    ItemView(QWidget *p);
+    ItemView(QWidget *p=0);
     virtual ~ItemView();
 
     void allowGroupedView();
     void addAction(QAction *act);
     void setMode(Mode m);
-    void hideBackButton();
     Mode viewMode() const { return mode; }
     void setLevel(int level, bool haveChildren=true);
     QAbstractItemView * view() const;
@@ -112,7 +110,6 @@ public:
     QModelIndexList selectedIndexes() const;
     QString searchText() const;
     void clearSearchText();
-    void setTopText(const QString &text);
     void setUniformRowHeights(bool v);
     void setAcceptDrops(bool v);
     void setDragDropOverwriteMode(bool v);
@@ -124,21 +121,29 @@ public:
     void setRootIsDecorated(bool v) { treeView->setRootIsDecorated(v); }
     void showIndex(const QModelIndex &idx, bool scrollTo);
     void focusSearch();
+    void setSearchLabelText(const QString &text);
+    void setSearchVisible(bool v);
+    bool isSearchActive() const;
     void setStartClosed(bool sc);
     bool isStartClosed();
-    void expandAll();
+    void expandAll(const QModelIndex &index=QModelIndex());
+    void expand(const QModelIndex &index);
+    void showMessage(const QString &message, int timeout);
+    void setBackgroundImage(const QIcon &icon);
 
 public Q_SLOTS:
-    void showSpinner();
+    void showSpinner(bool v=true);
     void hideSpinner();
     void collectionRemoved(quint32 key);
     void updateRows();
     void updateRows(const QModelIndex &idx);
     void backActivated();
+    void homeActivated();
     void setExpanded(const QModelIndex &idx, bool exp=true);
 
 Q_SIGNALS:
     void searchItems();
+    void searchIsActive(bool);
     void itemsSelected(bool);
     void doubleClicked(const QModelIndex &);
     void rootIndexSet(const QModelIndex &);
@@ -147,24 +152,26 @@ private Q_SLOTS:
     void itemClicked(const QModelIndex &index);
     void itemActivated(const QModelIndex &index);
     void delaySearchItems();
+    void activateItem(const QModelIndex &index, bool emitRootSet=true);
 
 private:
-    void activateItem(const QModelIndex &index, bool emitRootSet=true);
     QAction * getAction(const QModelIndex &index);
 
 private:
     QTimer *searchTimer;
     ProxyModel *itemModel;
     QAction *backAction;
+    QAction *homeAction;
     int currentLevel;
     Mode mode;
-    QString topText;
     QMap<int, QString> prevText;
     QModelIndex prevTopIndex;
     QSize iconGridSize;
     QSize listGridSize;
     GroupedView *groupedView;
     Spinner *spinner;
+    MessageOverlay *msgOverlay;
+    QIcon bgndIcon;
 };
 
 #endif
